@@ -8,13 +8,14 @@ train_arima <- function(.data, specials,
                         unitroot_spec = unitroot_options(), trace = FALSE,
                         fixed = NULL, method = NULL, ...) {
   if (length(measured_vars(.data)) > 1) {
-    abort("Only univariate responses are supported by ARIMA.")
+    cli::cli_abort("Only univariate responses are supported by ARIMA.")
   }
   
   # Get args
   if(length(specials$pdq) > 1 || length(specials$PDQ) > 1){
-    warn("Only one special for `pdq()` and `PDQ()` is allowed, defaulting to the first usage")
+    cli::cli_warn("Only one special for `pdq()` and `PDQ()` is allowed, defaulting to the first usage")
   }
+  
   pdq <- specials$pdq[[1]]
   PDQ <- specials$PDQ[[1]]
   period <- PDQ$period
@@ -24,7 +25,7 @@ train_arima <- function(.data, specials,
   y <- x <- ts(unclass(.data)[[measured_vars(.data)]], frequency = period)
 
   if (all(is.na(y))) {
-    abort("All observations are missing, a model cannot be estimated without data.")
+    cli::cli_abort("All observations are missing, a model cannot be estimated without data.")
   }
 
   # Get xreg
@@ -47,7 +48,7 @@ train_arima <- function(.data, specials,
       
       # Remove deficient regressors
       if(!is_empty(bad_regressors)){
-        warn(sprintf(
+        cli::cli_warn(sprintf(
           "Provided exogenous regressors are rank deficient, removing regressors: %s",
           paste("`", colnames(xreg)[bad_regressors], "`", sep = "", collapse = ", ")
         ))
@@ -72,8 +73,8 @@ train_arima <- function(.data, specials,
   if (NROW(model_opts) > 1) {
     model_opts <- filter(model_opts, !!enexpr(order_constraint))
     if (NROW(model_opts) == 0) {
-      if (mostly_specified) warn(mostly_specified_msg)
-      abort("There are no ARIMA models to choose from after imposing the `order_constraint`, please consider allowing more models.")
+      if (mostly_specified) cli::cli_warn(mostly_specified_msg)
+      cli::cli_abort("There are no ARIMA models to choose from after imposing the `order_constraint`, please consider allowing more models.")
     }
     wrap_arima <- possibly(quietly(stats::arima), NULL)
   }
@@ -96,8 +97,8 @@ train_arima <- function(.data, specials,
     if (!is.null(xreg)) {
       keep <- map_lgl(seas_D, function(.x) {
         if(.x*period >= nrow(xreg)) return(FALSE)
-        diff_xreg <- diff(xreg, lag = period, differences = .x)
-        !any(apply(diff_xreg, 2, is.constant))
+        dxreg <- diff(xreg, lag = period, differences = .x)
+        !any(apply(dxreg, 2, is.constant))
       })
       seas_D <- seas_D[keep]
     }
@@ -108,36 +109,40 @@ train_arima <- function(.data, specials,
     ))
     model_opts <- model_opts[model_opts$D == seas_D,]
   }
-  x <- diff(x, lag = period, differences = seas_D)
-  diff_xreg <- diff(xreg, lag = period, differences = seas_D)
+  dx <- diff(x, lag = period, differences = seas_D)
+  dxreg <- diff(xreg, lag = period, differences = seas_D)
+  
+  # Choose regular differencing
   if (length(seas_d <- unique(model_opts$d)) > 1) {
     require_package("feasts")
 
     # Valid xregs
     if (!is.null(xreg)) {
       keep <- map_lgl(seas_d, function(.x) {
-        if(.x >= nrow(diff_xreg)) return(FALSE)
-        diff_xreg <- diff(diff_xreg, differences = .x)
-        !any(apply(diff_xreg, 2, is.constant))
+        if(.x >= nrow(dxreg)) return(FALSE)
+        dxreg <- diff(dxreg, differences = .x)
+        !any(apply(dxreg, 2, is.constant))
       })
       seas_d <- seas_d[keep]
     }
 
-    seas_d <- unname(feasts::unitroot_ndiffs(stats::na.contiguous(x),
+    seas_d <- unname(feasts::unitroot_ndiffs(stats::na.contiguous(dx),
       alpha = unitroot_spec$ndiffs_alpha,
       unitroot_fn = unitroot_spec$ndiffs_pvalue,
       differences = seas_d
     ))
     model_opts <- model_opts[model_opts$d == seas_d,]
   }
+  dx <- diff(x, lag = period, differences = seas_d)
+  dxreg <- diff(xreg, differences = seas_d)
 
   # Check number of differences selected
-  if (length(seas_D) != 1) abort("Could not find appropriate number of seasonal differences.")
-  if (length(seas_d) != 1) abort("Could not find appropriate number of non-seasonal differences.")
+  if (length(seas_D) != 1) cli::cli_abort("Could not find appropriate number of seasonal differences.")
+  if (length(seas_d) != 1) cli::cli_abort("Could not find appropriate number of non-seasonal differences.")
   if (seas_D >= 2) {
-    warn("Having more than one seasonal difference is not recommended. Please consider using only one seasonal difference.")
+    cli::cli_warn("Having more than one seasonal difference is not recommended. Please consider using only one seasonal difference.")
   } else if (seas_D + seas_d > 2) {
-    warn("Having 3 or more differencing operations is not recommended. Please consider reducing the total number of differences.")
+    cli::cli_warn("Having 3 or more differencing operations is not recommended. Please consider reducing the total number of differences.")
   }
 
   # Find best model
@@ -204,7 +209,6 @@ train_arima <- function(.data, specials,
             }
           }
         )
-
         if (isTRUE(min(minroot) < 1 + 1e-2)) { # Previously 1+1e-3
           new <- NULL
         } # Don't like this model
@@ -236,7 +240,7 @@ train_arima <- function(.data, specials,
       method <- "CSS-ML"
     }
   } else {
-    if(isTRUE(approximation)) warn("Estimating ARIMA models with approximation is not supported when `method` is specified.")
+    if(isTRUE(approximation)) cli::cli_warn("Estimating ARIMA models with approximation is not supported when `method` is specified.")
     approximation <- FALSE
   }
   
@@ -252,12 +256,51 @@ train_arima <- function(.data, specials,
   }
   
   if (any((model_opts$d + model_opts$D > 1) & model_opts$constant)) {
-    warn("Model specification induces a quadratic or higher order polynomial trend. 
+    cli::cli_warn("Model specification induces a quadratic or higher order polynomial trend. 
 This is generally discouraged, consider removing the constant or reducing the number of differences.")
   }
   constant <- unique(model_opts$constant)
 
-  if (stepwise) {
+  # If the differencing produces constant data, return simple models
+  if (is.constant(dx)) {
+    # Only consider models with no AR or MA terms
+    model_opts <- model_opts[model_opts$p == 0 & model_opts$q == 0 & model_opts$P == 0 & model_opts$Q == 0, ]
+
+    # Check if any models remain
+    if (NROW(model_opts) == 0) {
+      cli::cli_abort("No ARIMA models without AR or MA terms are available for constant differenced data.\n\nConsider including 0 orders for p, q, P and Q in the model specification.")
+    }
+
+    # Prevent later re-estimation
+    approximation <- FALSE
+
+    # Handle constant differenced data
+    if (is.null(xreg)) {
+      has_constant <- (seas_D > 0 && seas_d == 0) || seas_d < 2
+      fixed <- if (has_constant) mean(dx / if (seas_D > 0 && seas_d == 0) period else 1, na.rm = TRUE) else NULL
+      
+      if (seas_d >= 2 && seas_D == 0) {
+        cli::cli_abort("Data follows a simple polynomial and is unsuitable for ARIMA modelling.")
+      }
+      
+      est_ic <- compare_arima(
+        0, seas_d, 0,
+        0, seas_D, 0, 
+        constant = has_constant
+      )
+    } else {
+      # Perfect regression
+      has_constant <- FALSE
+      est_ic <- compare_arima(
+        0, seas_d, 0,
+        0, seas_D, 0, 
+        constant = FALSE
+      )
+    }
+
+    model_opts <- model_opts[model_opts$constant == has_constant, ]
+  }
+  else if (stepwise) {
     # Prepare model comparison vector
     est_ic <- rep(NA_integer_, NROW(model_opts))
     best_ic <- Inf
@@ -270,6 +313,15 @@ This is generally discouraged, consider removing the constant or reducing the nu
       ma = c(0, seas_d, max(pdq$q) > 0, 0, seas_D, max(PDQ$Q) > 0, constant[1])
     )
     step_order <- unique(stats::na.omit(match(initial_opts, lapply(split(model_opts, seq_len(NROW(model_opts))), as.numeric))))
+    # If none of the initial models are valid, start from the closest model to the initial
+    if (length(step_order) == 0) {
+      step_order <- order(
+        (model_opts$p - pdq$p_init)^2 + (model_opts$q - pdq$q_init)^2 +
+          (model_opts$P - PDQ$P_init)^2 + (model_opts$Q - PDQ$Q_init)^2,
+        model_opts$P, model_opts$Q, model_opts$p, model_opts$q
+      )[1L]
+    }
+    
     initial <- TRUE
 
     if(trace) {
@@ -320,33 +372,46 @@ This is generally discouraged, consider removing the constant or reducing the nu
       cat("\n--- Re-estimating best models without approximation ---\n\n")
     }
     
+    approx_best <- best
+    approx_spec <- which.min(est_ic)
+
     method <- "CSS-ML"
     best <- NULL
     sm_best <- Inf
     step_order <- order(est_ic)[seq_len(sum(!is.na(est_ic)))]
     est_ic <- rep_len(Inf, length(est_ic)) # Ignore all approximate models until re-estimated
-    for (mod_spec in step_order)
-    {
-      est_ic[mod_spec] <- do.call(compare_arima, model_opts[mod_spec, ])
-      if (isTRUE(is.finite(est_ic[mod_spec]))) {
+    for (i in step_order) {
+      est_ic[i] <- do.call(compare_arima, model_opts[i, ])
+      if (has_mle_fit <-isTRUE(is.finite(est_ic[i]))) {
+        mod_spec <- i
         break
       }
     }
+
+    if(!has_mle_fit) {
+      if(trace) {
+        cat("\n--- Re-estimating best models without approximation failed, returning CSS fits ---\n\n")
+      }
+      best <- approx_best
+      mod_spec <- approx_spec
+    }
   } else {
     mod_spec <- which.min(est_ic)
   }
 
   if (is.null(best)) {
-    if (mostly_specified) warn(mostly_specified_msg)
-    abort("Could not find an appropriate ARIMA model.\nThis is likely because automatic selection does not select models with characteristic roots that may be numerically unstable.\nFor more details, refer to https://otexts.com/fpp3/arima-r.html#plotting-the-characteristic-roots")
+    if (mostly_specified) cli::cli_warn(mostly_specified_msg)
+    cli::cli_abort("Could not find an appropriate ARIMA model.\nThis is likely because automatic selection does not select models with characteristic roots that may be numerically unstable.\nFor more details, refer to https://otexts.com/fpp3/arima-r.html#plotting-the-characteristic-roots")
   }
 
   # Compute ARMA roots
   ar <- best$model$phi
   ma <- best$model$theta
-  arroot <- if (is_empty(ar) || !any(abs(ar) > 0)) cpl() else polyroot(c(1, -ar[seq_len(max(which(abs(ar) > 1e-8)))]))
-  maroot <- if (is_empty(ma) || !any(abs(ma) > 0)) cpl() else polyroot(c(1, ma[seq_len(max(which(abs(ma) > 1e-8)))]))
-
+  armax <- max(which(abs(ar) > 1e-8) %0% 0L)
+  mamax <- max(which(abs(ma) > 1e-8) %0% 0L)
+  arroot <- polyroot(c(1, -ar[seq_len(armax)]))
+  maroot <- polyroot(c(1, ma[seq_len(mamax)]))
+  
   fit_coef <- coef(best)
   
   fit_se <- set_names(numeric(length(fit_coef)), names(fit_coef))
@@ -355,14 +420,14 @@ This is generally discouraged, consider removing the constant or reducing the nu
   if (is_empty(fit_se)) {
     fit_se <- NULL
   }
-  else if (model_opts[which.min(est_ic), "constant"] && is.null(xreg)) {
+  else if (model_opts[mod_spec, "constant"] && is.null(xreg)) {
     fit_coef["constant"] <- fit_coef["constant"] * (1 - sum(best$model$phi))
     fit_se["constant"] <- fit_se["constant"] * (1 - sum(best$model$phi))
   }
 
   # Compute regression residuals
   reg_resid <- as.numeric(y)
-  if (model_opts[which.min(est_ic), "constant"]) {
+  if (model_opts[mod_spec, "constant"]) {
     xreg <- cbind(xreg, constant = arima_constant(length(y), seas_d, seas_D, period))
   }
   if (!is.null(xreg)) {
@@ -420,7 +485,7 @@ specials_arima <- new_specials(
     p_init <- p[which.min(abs(p - p_init))]
     q_init <- q[which.min(abs(q - q_init))]
     if(!all(grepl("^(ma|ar)\\d+", names(fixed)))){
-      abort("The 'fixed' coefficients for pdq() must begin with ar or ma, followed by a lag number.")
+      cli::cli_abort("The 'fixed' coefficients for pdq() must begin with ar or ma, followed by a lag number.")
     }
     as.list(environment())
   },
@@ -429,7 +494,7 @@ specials_arima <- new_specials(
                  fixed = list()) {
     period <- get_frequencies(period, self$data, .auto = "smallest")
     if (period < 1) {
-      abort("The seasonal period must be greater than or equal to 1.")
+      cli::cli_abort("The seasonal period must be greater than or equal to 1.")
     } else if (period == 1) {
       # Not seasonal
       P <- 0
@@ -440,13 +505,13 @@ specials_arima <- new_specials(
       P <- P[P <= floor(NROW(self$data) / 3 / period)]
       Q <- Q[Q <= floor(NROW(self$data) / 3 / period)]
       if(length(P) == 0 || length(Q) == 0) {
-        abort("Not enough data to estimate a model with those options of P and Q. Consider allowing smaller values of P and Q to be selected.")
+        cli::cli_abort("Not enough data to estimate a model with those options of P and Q. Consider allowing smaller values of P and Q to be selected.")
       }
     }
     P_init <- P[which.min(abs(P - P_init))]
     Q_init <- Q[which.min(abs(Q - Q_init))]
     if(!all(grepl("^(sma|sar)\\d+", names(fixed)))){
-      abort("The 'fixed' coefficients for PDQ() must begin with sar or sma, followed by a lag number.")
+      cli::cli_abort("The 'fixed' coefficients for PDQ() must begin with sar or sma, followed by a lag number.")
     }
     as.list(environment())
   },
@@ -547,7 +612,8 @@ specials_arima <- new_specials(
 #' For details of the estimation algorithm, see the
 #' \code{\link[stats]{arima}} function in the stats package.
 #'
-
+#' @aliases pdq PDQ
+#' 
 #' @section Specials:
 #' 
 #' The _specials_ define the space over which `ARIMA` will search for the model that best fits the data. If the RHS of `formula` is left blank, the default search space is given by `pdq() + PDQ()`: that is, a model with candidate seasonal and nonseasonal terms, but no exogenous regressors. Note that a seasonal model requires at least 2 full seasons of data; if this is not available, `ARIMA` will revert to a nonseasonal model with a warning.
@@ -610,6 +676,14 @@ specials_arima <- new_specials(
 #'
 #' @return A model specification.
 #'
+#' @examplesIf !requireNamespace("feasts", quietly = TRUE)
+#' # The feasts package is required for automatic ARIMA model selection.
+#' # Install it with: install.packages("feasts")
+#' 
+#' @examplesIf !requireNamespace("urca", quietly = TRUE)
+#' # The urca package is required for ARIMA models to automatically select `d`
+#' # Install it with: install.packages("urca")
+#' 
 #' @examples
 #' # Manual ARIMA specification
 #' USAccDeaths %>%
@@ -620,6 +694,8 @@ specials_arima <- new_specials(
 #' # Automatic ARIMA specification
 #' library(tsibble)
 #' library(dplyr)
+#' library(feasts)
+#' library(urca)
 #' tsibbledata::global_economy %>%
 #'   filter(Country == "Australia") %>%
 #'   model(ARIMA(log(GDP) ~ Population))
@@ -716,7 +792,7 @@ residuals.ARIMA <- function(object, type = c("innovation", "regression"), ...) {
     object$est[[".regression_resid"]]
   }
   else {
-    abort(sprintf('Residuals of `type = "%s"` are not supported by ARIMA models', type))
+    cli::cli_abort(sprintf('Residuals of `type = "%s"` are not supported by ARIMA models', type))
   }
 }
 
@@ -808,22 +884,6 @@ report.ARIMA <- function(object, ...) {
 #' @export
 forecast.ARIMA <- function(object, new_data = NULL, specials = NULL,
                            bootstrap = FALSE, times = 5000, ...) {
-  # Check position of new_data in model history
-  if(inherits_any(object$tsp$range, c("yearweek", "yearmonth", "yearquarter"))) {
-    fc_start <- object$tsp$range[2]+round(as.numeric(diff(object$tsp$range)+1)/nrow(object$est), 6)
-  } else {
-    # Try to use difftime
-    interval <- unclass(object$tsp$interval)
-    interval <- Filter(function(x) x!=0, interval)
-    time_unit <- switch(names(interval), day = "days", hour = "hours", minute = "mins", second = "secs")
-    if(!is.null(time_unit)) interval[[1]] <- as.difftime(interval[[1]], units = time_unit)
-    fc_start <- object$tsp$range[2] + interval[[1]]
-  }
-  
-  if (unclass(new_data)[[index_var(new_data)]][1] != fc_start) {
-    abort("Forecasts from an ARIMA model must start one step beyond the end of the trained data.")
-  }
-  
   if (bootstrap) {
     sim <- map(seq_len(times), function(x) generate(object, new_data, specials, bootstrap = TRUE)[[".sim"]]) %>%
       transpose() %>%
@@ -1053,7 +1113,7 @@ refit.ARIMA <- function(object, new_data, specials = NULL, reestimate = FALSE, .
 #     stream_start <- object$tsp$range[2] + as.difftime(interval[[1]], units = time_unit)
 #   }
 #   if (unclass(new_data)[[index_var(new_data)]][1] != stream_start) {
-#     abort("Streaming to an ARIMA model must start one step beyond the end of the trained data.")
+#     cli::cli_abort("Streaming to an ARIMA model must start one step beyond the end of the trained data.")
 #   }
 #   
 #   y <- unclass(new_data)[[measured_vars(new_data)]]
