@@ -46,7 +46,7 @@ etsmodel <- function(y, m, errortype, trendtype, seasontype, damped,
   }
 
   if (!check.param(alpha, beta, gamma, phi, lower, upper, bounds, m)) {
-    abort(sprintf(
+    cli::cli_abort(sprintf(
       "Parameters out of range for ETS(%s,%s%s,%s) model",
       errortype, trendtype, ifelse(damped, "d", ""), seasontype
     ))
@@ -61,7 +61,7 @@ etsmodel <- function(y, m, errortype, trendtype, seasontype, damped,
 
   np <- length(par)
   if (np >= length(y) - 1) { # Not enough data to continue
-    abort("Not enough data to estimate this ETS model.")
+    cli::cli_abort("Not enough data to estimate this ETS model.")
   }
 
   env <- etsTargetFunctionInit(
@@ -140,16 +140,11 @@ estimate_ets <- function(y, m, init.state, errortype, trendtype, seasontype,
     alpha = unname(alpha), beta = unname(beta),
     gamma = unname(gamma), phi = unname(phi), init.state
   )
-  if (errortype == "A") {
-    fits <- y - e$e
-  } else {
-    fits <- y / (1 + e$e)
-  }
 
   return(list(
     loglik = -0.5 * e$lik, aic = aic, bic = bic, aicc = aicc,
     mse = mse, amse = amse, mae = mae,
-    residuals = e$e, fitted = fits,
+    residuals = e$e, fitted = e$fits,
     states = states, par = fit.par
   ))
 }
@@ -161,12 +156,12 @@ etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasonty
   names(par.noopt) <- pnames2
   alpha <- c(par["alpha"], par.noopt["alpha"])["alpha"]
   if (is.na(alpha)) {
-    stop("alpha problem!")
+    cli::cli_abort("alpha problem!")
   }
   if (trendtype != "N") {
     beta <- c(par["beta"], par.noopt["beta"])["beta"]
     if (is.na(beta)) {
-      stop("beta Problem!")
+      cli::cli_abort("beta Problem!")
     }
   }
   else {
@@ -175,7 +170,7 @@ etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasonty
   if (seasontype != "N") {
     gamma <- c(par["gamma"], par.noopt["gamma"])["gamma"]
     if (is.na(gamma)) {
-      stop("gamma Problem!")
+      cli::cli_abort("gamma Problem!")
     }
   }
   else {
@@ -185,7 +180,7 @@ etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasonty
   if (damped) {
     phi <- c(par["phi"], par.noopt["phi"])["phi"]
     if (is.na(phi)) {
-      stop("phi Problem!")
+      cli::cli_abort("phi Problem!")
     }
   }
   else {
@@ -259,7 +254,7 @@ initparam <- function(alpha, beta, gamma, phi, trendtype, seasontype, damped, lo
     lower[1L:3L] <- 0
     upper[1L:3L] <- 1e-3
   } else if (any(lower > upper)) {
-    stop("Inconsistent parameter boundaries")
+    cli::cli_abort("Inconsistent parameter boundaries")
   }
 
   # Select alpha
@@ -344,7 +339,7 @@ initstate <- function(y, m, trendtype, seasontype) {
     # Do decomposition
     n <- length(y)
     if (n < 4) {
-      stop("You've got to be joking (not enough data).")
+      cli::cli_abort("You've got to be joking (not enough data).")
     } else if (n < 3 * m) # Fit simple Fourier model.
       {
         fouriery <- as.matrix(fourier(seq_along(y), m, 1))
@@ -429,7 +424,7 @@ pegelsresid.C <- function(y, m, init.state, errortype, trendtype, seasontype, da
   p <- length(init.state)
   x <- numeric(p * (n + 1))
   x[1:p] <- init.state
-  e <- numeric(n)
+  e <- fits <- numeric(n)
   lik <- 0
   if (!damped) {
     phi <- 1
@@ -457,18 +452,15 @@ pegelsresid.C <- function(y, m, init.state, errortype, trendtype, seasontype, da
     as.double(gamma),
     as.double(phi),
     as.double(e),
+    as.double(fits),
     as.double(lik),
     as.double(amse),
     as.integer(nmse),
+    NAOK = TRUE,
     PACKAGE = "fable"
   )
-  if (!is.na(Cout[[13]])) {
-    if (abs(Cout[[13]] + 99999) < 1e-7) {
-      Cout[[13]] <- NA
-    }
-  }
 
-  return(list(lik = Cout[[13]], amse = Cout[[14]], e = Cout[[12]], states = matrix(Cout[[3]], nrow = n + 1, ncol = p, byrow = TRUE)))
+  return(list(lik = Cout[[14]], amse = Cout[[15]], e = Cout[[12]], fits = Cout[[13]], states = matrix(Cout[[3]], nrow = n + 1, ncol = p, byrow = TRUE)))
 }
 
 admissible <- function(alpha, beta, gamma, phi, m) {
